@@ -21,8 +21,6 @@
 #'
 #' @examples
 #' findAphia("cod")
-#' \dontrun{
-#' findAphia("cod")
 #' findAphia("Gadus morhua", latin = TRUE)
 #'
 #' # Multiple matches
@@ -31,7 +29,7 @@
 #' # Regular expressions
 #' findAphia("ray", regex = TRUE, full = TRUE)
 #' findAphia("Sebastes", latin = TRUE, regex = TRUE, full = TRUE)
-#' }
+#'
 #' @export
 
 findAphia <- function(species, latin = FALSE, regex = FALSE, full = FALSE) {
@@ -48,7 +46,7 @@ findAphia <- function(species, latin = FALSE, regex = FALSE, full = FALSE) {
            else
              grep(paste0("^", pattern, "$"), ...)
     if (length(out) == 0)
-      stop("\nSpecies pattern '", pattern, "' not found")
+      warning("\nSpecies pattern '", pattern, "' not found")
     if (length(out) > 1 && !regex)
       message("\nSpecies pattern '", pattern, "' returned multiple matches")
     out
